Index: fetch_configs/depot_tools.py |
diff --git a/recipes/depot_tools.py b/fetch_configs/depot_tools.py |
similarity index 89% |
rename from recipes/depot_tools.py |
rename to fetch_configs/depot_tools.py |
index 7c3b91cec50682dfa33cd90a4510e1d14ea4bd5f..f94864974199abf2768f80abdc7ec83d5331e303 100644 |
--- a/recipes/depot_tools.py |
+++ b/fetch_configs/depot_tools.py |
@@ -4,13 +4,13 @@ |
import sys |
-import recipe_util # pylint: disable=F0401 |
+import config_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class DepotTools(recipe_util.Recipe): |
- """Basic Recipe class for DepotTools.""" |
+class DepotTools(config_util.Config): |
+ """Basic Config class for DepotTools.""" |
@staticmethod |
def fetch_spec(props): |